Coordinate Reference System for jpmap
jpmap_crs.RdReturns the projected coordinate reference system used by jpmap.
Value
An sf::st_crs() object.

jpmap_crs.RdReturns the projected coordinate reference system used by jpmap.
An sf::st_crs() object.